@@ -15,7 +15,8 @@ class NMPipeline:
         self.device = "cuda" if torch.cuda.is_available() and use_cuda else "cpu"
         self.model.to(self.device)
 
-        assert self.model.__class__.__name__ in ["T5ForConditionalGeneration"]
+        if self.model.__class__.__name__ not in ["T5ForConditionalGeneration"]:
+            raise AssertionError
 
         if "T5ForConditionalGeneration" in self.model.__class__.__name__:
             self.model_type = "t5"
@@ -80,7 +81,8 @@ class K2TPipeline:
         self.device = "cuda" if torch.cuda.is_available() and use_cuda else "cpu"
         self.model.to(self.device)
 
-        assert self.model.__class__.__name__ in ["T5ForConditionalGeneration"]
+        if self.model.__class__.__name__ not in ["T5ForConditionalGeneration"]:
+            raise AssertionError
 
         if "T5ForConditionalGeneration" in self.model.__class__.__name__:
             self.model_type = "t5"
